PrimitiveDateTime

Type Alias PrimitiveDateTime 

pub type PrimitiveDateTime = PlainDateTime;
A PlainDateTime under its original name.

This type is not currently deprecated, but it likely will be in the future. Use PlainDateTime when writing new code. In the next breaking release, this alias will be removed.

Aliased Type

pub struct PrimitiveDateTime {
    time: Time,
    date: Date,
}

Fields

time: Time
Available on little-endian only.
date: Date
Available on little-endian only.